/****************************************************************************
** Meta object code from reading C++ file 'kstatusnotifieritem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knotifications-5.39.0/src/kstatusnotifieritem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kstatusnotifieritem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KStatusNotifierItem_t {
    QByteArrayData data[43];
    char stringdata0[569];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KStatusNotifierItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KStatusNotifierItem_t qt_meta_stringdata_KStatusNotifierItem = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KStatusNotifierItem"
QT_MOC_LITERAL(1, 20, 15), // "scrollRequested"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 5), // "delta"
QT_MOC_LITERAL(4, 43, 15), // "Qt::Orientation"
QT_MOC_LITERAL(5, 59, 11), // "orientation"
QT_MOC_LITERAL(6, 71, 17), // "activateRequested"
QT_MOC_LITERAL(7, 89, 6), // "active"
QT_MOC_LITERAL(8, 96, 3), // "pos"
QT_MOC_LITERAL(9, 100, 26), // "secondaryActivateRequested"
QT_MOC_LITERAL(10, 127, 8), // "activate"
QT_MOC_LITERAL(11, 136, 13), // "serviceChange"
QT_MOC_LITERAL(12, 150, 4), // "name"
QT_MOC_LITERAL(13, 155, 8), // "oldOwner"
QT_MOC_LITERAL(14, 164, 8), // "newOwner"
QT_MOC_LITERAL(15, 173, 23), // "checkForRegisteredHosts"
QT_MOC_LITERAL(16, 197, 16), // "registerToDaemon"
QT_MOC_LITERAL(17, 214, 22), // "contextMenuAboutToShow"
QT_MOC_LITERAL(18, 237, 9), // "maybeQuit"
QT_MOC_LITERAL(19, 247, 15), // "minimizeRestore"
QT_MOC_LITERAL(20, 263, 8), // "hideMenu"
QT_MOC_LITERAL(21, 272, 16), // "legacyWheelEvent"
QT_MOC_LITERAL(22, 289, 15), // "legacyActivated"
QT_MOC_LITERAL(23, 305, 33), // "QSystemTrayIcon::ActivationRe..."
QT_MOC_LITERAL(24, 339, 8), // "category"
QT_MOC_LITERAL(25, 348, 12), // "ItemCategory"
QT_MOC_LITERAL(26, 361, 5), // "title"
QT_MOC_LITERAL(27, 367, 6), // "status"
QT_MOC_LITERAL(28, 374, 10), // "ItemStatus"
QT_MOC_LITERAL(29, 385, 8), // "iconName"
QT_MOC_LITERAL(30, 394, 15), // "overlayIconName"
QT_MOC_LITERAL(31, 410, 17), // "attentionIconName"
QT_MOC_LITERAL(32, 428, 15), // "toolTipIconName"
QT_MOC_LITERAL(33, 444, 12), // "toolTipTitle"
QT_MOC_LITERAL(34, 457, 15), // "toolTipSubTitle"
QT_MOC_LITERAL(35, 473, 7), // "Passive"
QT_MOC_LITERAL(36, 481, 6), // "Active"
QT_MOC_LITERAL(37, 488, 14), // "NeedsAttention"
QT_MOC_LITERAL(38, 503, 17), // "ApplicationStatus"
QT_MOC_LITERAL(39, 521, 14), // "Communications"
QT_MOC_LITERAL(40, 536, 14), // "SystemServices"
QT_MOC_LITERAL(41, 551, 8), // "Hardware"
QT_MOC_LITERAL(42, 560, 8) // "Reserved"

    },
    "KStatusNotifierItem\0scrollRequested\0"
    "\0delta\0Qt::Orientation\0orientation\0"
    "activateRequested\0active\0pos\0"
    "secondaryActivateRequested\0activate\0"
    "serviceChange\0name\0oldOwner\0newOwner\0"
    "checkForRegisteredHosts\0registerToDaemon\0"
    "contextMenuAboutToShow\0maybeQuit\0"
    "minimizeRestore\0hideMenu\0legacyWheelEvent\0"
    "legacyActivated\0QSystemTrayIcon::ActivationReason\0"
    "category\0ItemCategory\0title\0status\0"
    "ItemStatus\0iconName\0overlayIconName\0"
    "attentionIconName\0toolTipIconName\0"
    "toolTipTitle\0toolTipSubTitle\0Passive\0"
    "Active\0NeedsAttention\0ApplicationStatus\0"
    "Communications\0SystemServices\0Hardware\0"
    "Reserved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KStatusNotifierItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       9,  120, // properties
       2,  147, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   84,    2, 0x06 /* Public */,
       6,    2,   89,    2, 0x06 /* Public */,
       9,    1,   94,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   97,    2, 0x0a /* Public */,
      10,    0,  100,    2, 0x2a /* Public | MethodCloned */,
      11,    3,  101,    2, 0x08 /* Private */,
      15,    0,  108,    2, 0x08 /* Private */,
      16,    0,  109,    2, 0x08 /* Private */,
      17,    0,  110,    2, 0x08 /* Private */,
      18,    0,  111,    2, 0x08 /* Private */,
      19,    0,  112,    2, 0x08 /* Private */,
      20,    0,  113,    2, 0x08 /* Private */,
      21,    1,  114,    2, 0x08 /* Private */,
      22,    1,  117,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Bool, QMetaType::QPoint,    7,    8,
    QMetaType::Void, QMetaType::QPoint,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::QPoint,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   12,   13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 23,    2,

 // properties: name, type, flags
      24, 0x80000000 | 25, 0x0009510b,
      26, QMetaType::QString, 0x00095103,
      27, 0x80000000 | 28, 0x0009510b,
      29, QMetaType::QString, 0x00095003,
      30, QMetaType::QString, 0x00095003,
      31, QMetaType::QString, 0x00095003,
      32, QMetaType::QString, 0x00095003,
      33, QMetaType::QString, 0x00095103,
      34, QMetaType::QString, 0x00095103,

 // enums: name, flags, count, data
      28, 0x0,    3,  155,
      25, 0x0,    5,  161,

 // enum data: key, value
      35, uint(KStatusNotifierItem::Passive),
      36, uint(KStatusNotifierItem::Active),
      37, uint(KStatusNotifierItem::NeedsAttention),
      38, uint(KStatusNotifierItem::ApplicationStatus),
      39, uint(KStatusNotifierItem::Communications),
      40, uint(KStatusNotifierItem::SystemServices),
      41, uint(KStatusNotifierItem::Hardware),
      42, uint(KStatusNotifierItem::Reserved),

       0        // eod
};

void KStatusNotifierItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KStatusNotifierItem *_t = static_cast<KStatusNotifierItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->scrollRequested((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::Orientation(*)>(_a[2]))); break;
        case 1: _t->activateRequested((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 2: _t->secondaryActivateRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 3: _t->activate((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 4: _t->activate(); break;
        case 5: _t->d->serviceChange((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 6: _t->d->checkForRegisteredHosts(); break;
        case 7: _t->d->registerToDaemon(); break;
        case 8: _t->d->contextMenuAboutToShow(); break;
        case 9: _t->d->maybeQuit(); break;
        case 10: _t->d->minimizeRestore(); break;
        case 11: _t->d->hideMenu(); break;
        case 12: _t->d->legacyWheelEvent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->d->legacyActivated((*reinterpret_cast< QSystemTrayIcon::ActivationReason(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KStatusNotifierItem::*_t)(int , Qt::Orientation );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KStatusNotifierItem::scrollRequested)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KStatusNotifierItem::*_t)(bool , const QPoint & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KStatusNotifierItem::activateRequested)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KStatusNotifierItem::*_t)(const QPoint & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KStatusNotifierItem::secondaryActivateRequested)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KStatusNotifierItem *_t = static_cast<KStatusNotifierItem *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< ItemCategory*>(_v) = _t->category(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast< ItemStatus*>(_v) = _t->status(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->iconName(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->overlayIconName(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->attentionIconName(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->toolTipIconName(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->toolTipTitle(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->toolTipSubTitle(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KStatusNotifierItem *_t = static_cast<KStatusNotifierItem *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCategory(*reinterpret_cast< ItemCategory*>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setStatus(*reinterpret_cast< ItemStatus*>(_v)); break;
        case 3: _t->setIconByName(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setOverlayIconByName(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setAttentionIconByName(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setToolTipIconByName(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setToolTipTitle(*reinterpret_cast< QString*>(_v)); break;
        case 8: _t->setToolTipSubTitle(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KStatusNotifierItem::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KStatusNotifierItem.data,
      qt_meta_data_KStatusNotifierItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KStatusNotifierItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KStatusNotifierItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KStatusNotifierItem.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KStatusNotifierItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KStatusNotifierItem::scrollRequested(int _t1, Qt::Orientation _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KStatusNotifierItem::activateRequested(bool _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KStatusNotifierItem::secondaryActivateRequested(const QPoint & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
