/****************************************************************************
** Meta object code from reading C++ file 'knotification.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knotifications-5.39.0/src/knotification.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knotification.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNotification_t {
    QByteArrayData data[16];
    char stringdata0[152];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNotification_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNotification_t qt_meta_stringdata_KNotification = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KNotification"
QT_MOC_LITERAL(1, 14, 9), // "activated"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 6), // "action"
QT_MOC_LITERAL(4, 32, 16), // "action1Activated"
QT_MOC_LITERAL(5, 49, 16), // "action2Activated"
QT_MOC_LITERAL(6, 66, 16), // "action3Activated"
QT_MOC_LITERAL(7, 83, 6), // "closed"
QT_MOC_LITERAL(8, 90, 7), // "ignored"
QT_MOC_LITERAL(9, 98, 8), // "activate"
QT_MOC_LITERAL(10, 107, 5), // "close"
QT_MOC_LITERAL(11, 113, 11), // "raiseWidget"
QT_MOC_LITERAL(12, 125, 3), // "ref"
QT_MOC_LITERAL(13, 129, 5), // "deref"
QT_MOC_LITERAL(14, 135, 9), // "sendEvent"
QT_MOC_LITERAL(15, 145, 6) // "update"

    },
    "KNotification\0activated\0\0action\0"
    "action1Activated\0action2Activated\0"
    "action3Activated\0closed\0ignored\0"
    "activate\0close\0raiseWidget\0ref\0deref\0"
    "sendEvent\0update"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNotification[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x06 /* Public */,
       1,    1,   90,    2, 0x06 /* Public */,
       4,    0,   93,    2, 0x06 /* Public */,
       5,    0,   94,    2, 0x06 /* Public */,
       6,    0,   95,    2, 0x06 /* Public */,
       7,    0,   96,    2, 0x06 /* Public */,
       8,    0,   97,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   98,    2, 0x0a /* Public */,
       9,    0,  101,    2, 0x2a /* Public | MethodCloned */,
      10,    0,  102,    2, 0x0a /* Public */,
      11,    0,  103,    2, 0x0a /* Public */,
      12,    0,  104,    2, 0x0a /* Public */,
      13,    0,  105,    2, 0x0a /* Public */,
      14,    0,  106,    2, 0x0a /* Public */,
      15,    0,  107,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::UInt,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KNotification::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KNotification *_t = static_cast<KNotification *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activated(); break;
        case 1: _t->activated((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 2: _t->action1Activated(); break;
        case 3: _t->action2Activated(); break;
        case 4: _t->action3Activated(); break;
        case 5: _t->closed(); break;
        case 6: _t->ignored(); break;
        case 7: _t->activate((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 8: _t->activate(); break;
        case 9: _t->close(); break;
        case 10: _t->raiseWidget(); break;
        case 11: _t->ref(); break;
        case 12: _t->deref(); break;
        case 13: _t->sendEvent(); break;
        case 14: _t->update(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KNotification::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::activated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KNotification::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::activated)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KNotification::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::action1Activated)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KNotification::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::action2Activated)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KNotification::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::action3Activated)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KNotification::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::closed)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KNotification::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KNotification::ignored)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject KNotification::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KNotification.data,
      qt_meta_data_KNotification,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNotification::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNotification::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNotification.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KNotification::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KNotification::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KNotification::activated(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KNotification::action1Activated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KNotification::action2Activated()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KNotification::action3Activated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KNotification::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KNotification::ignored()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
