/****************************************************************************
** Meta object code from reading C++ file 'notifybypopup.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/knotifications-5.39.0/src/notifybypopup.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notifybypopup.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NotifyByPopup_t {
    QByteArrayData data[15];
    char stringdata0[283];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NotifyByPopup_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NotifyByPopup_t qt_meta_stringdata_NotifyByPopup = {
    {
QT_MOC_LITERAL(0, 0, 13), // "NotifyByPopup"
QT_MOC_LITERAL(1, 14, 23), // "onPassivePopupDestroyed"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 25), // "onPassivePopupLinkClicked"
QT_MOC_LITERAL(4, 65, 4), // "link"
QT_MOC_LITERAL(5, 70, 21), // "onServiceOwnerChanged"
QT_MOC_LITERAL(6, 92, 33), // "onGalagoNotificationActionInv..."
QT_MOC_LITERAL(7, 126, 14), // "notificationId"
QT_MOC_LITERAL(8, 141, 9), // "actionKey"
QT_MOC_LITERAL(9, 151, 26), // "onGalagoNotificationClosed"
QT_MOC_LITERAL(10, 178, 19), // "onGalagoServerReply"
QT_MOC_LITERAL(11, 198, 24), // "QDBusPendingCallWatcher*"
QT_MOC_LITERAL(12, 223, 11), // "callWatcher"
QT_MOC_LITERAL(13, 235, 34), // "onGalagoServerCapabilitiesRec..."
QT_MOC_LITERAL(14, 270, 12) // "capabilities"

    },
    "NotifyByPopup\0onPassivePopupDestroyed\0"
    "\0onPassivePopupLinkClicked\0link\0"
    "onServiceOwnerChanged\0"
    "onGalagoNotificationActionInvoked\0"
    "notificationId\0actionKey\0"
    "onGalagoNotificationClosed\0"
    "onGalagoServerReply\0QDBusPendingCallWatcher*\0"
    "callWatcher\0onGalagoServerCapabilitiesReceived\0"
    "capabilities"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NotifyByPopup[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x08 /* Private */,
       3,    1,   50,    2, 0x08 /* Private */,
       5,    3,   53,    2, 0x08 /* Private */,
       6,    2,   60,    2, 0x08 /* Private */,
       9,    2,   65,    2, 0x08 /* Private */,
      10,    1,   70,    2, 0x08 /* Private */,
      13,    1,   73,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, QMetaType::UInt, QMetaType::QString,    7,    8,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt,    2,    2,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::QStringList,   14,

       0        // eod
};

void NotifyByPopup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NotifyByPopup *_t = static_cast<NotifyByPopup *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onPassivePopupDestroyed(); break;
        case 1: _t->onPassivePopupLinkClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->onServiceOwnerChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->onGalagoNotificationActionInvoked((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->onGalagoNotificationClosed((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 5: _t->onGalagoServerReply((*reinterpret_cast< QDBusPendingCallWatcher*(*)>(_a[1]))); break;
        case 6: _t->onGalagoServerCapabilitiesReceived((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject NotifyByPopup::staticMetaObject = {
    { &KNotificationPlugin::staticMetaObject, qt_meta_stringdata_NotifyByPopup.data,
      qt_meta_data_NotifyByPopup,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *NotifyByPopup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotifyByPopup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NotifyByPopup.stringdata0))
        return static_cast<void*>(this);
    return KNotificationPlugin::qt_metacast(_clname);
}

int NotifyByPopup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KNotificationPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
